@@ -343,7 +343,19 @@ impl<'dir> File<'dir> {
     /// Determine the full path resolving all symbolic links on demand.
     pub fn absolute_path(&self) -> Option<&PathBuf> {
         self.absolute_path
-            .get_or_init(|| std::fs::canonicalize(&self.path).ok())
+            .get_or_init(|| {
+                if self.link_target().is_broken() {
+                    // workaround for broken symlinks to get absolute path for parent and then
+                    // append name of file; std::fs::canonicalize requires all path components
+                    // (including the last one) to exist
+                    self.path
+                        .parent()
+                        .and_then(|parent| std::fs::canonicalize(parent).ok())
+                        .map(|p| p.join(self.name.clone()))
+                } else {
+                    std::fs::canonicalize(&self.path).ok()
+                }
+            })
             .as_ref()
     }
 
@@ -875,6 +887,45 @@ impl<'dir> File<'dir> {
             context: SecurityContextType::None,
         }
     }
+
+    /// User file flags.
+    #[cfg(any(
+        target_os = "macos",
+        target_os = "freebsd",
+        target_os = "netbsd",
+        target_os = "openbsd",
+        target_os = "dragonfly"
+    ))]
+    pub fn flags(&self) -> f::Flags {
+        #[cfg(target_os = "dragonfly")]
+        use std::os::dragonfly::fs::MetadataExt;
+        #[cfg(target_os = "freebsd")]
+        use std::os::freebsd::fs::MetadataExt;
+        #[cfg(target_os = "macos")]
+        use std::os::macos::fs::MetadataExt;
+        #[cfg(target_os = "netbsd")]
+        use std::os::netbsd::fs::MetadataExt;
+        #[cfg(target_os = "openbsd")]
+        use std::os::openbsd::fs::MetadataExt;
+        f::Flags(self.metadata.st_flags())
+    }
+
+    #[cfg(windows)]
+    pub fn flags(&self) -> f::Flags {
+        f::Flags(self.metadata.file_attributes())
+    }
+
+    #[cfg(not(any(
+        target_os = "macos",
+        target_os = "freebsd",
+        target_os = "netbsd",
+        target_os = "openbsd",
+        target_os = "dragonfly",
+        target_os = "windows"
+    )))]
+    pub fn flags(&self) -> f::Flags {
+        f::Flags(0)
+    }
 }
 
 impl<'a> AsRef<File<'a>> for File<'a> {
