@@ -25,6 +25,7 @@ impl Icons {
     const EMACS: char           = '\u{e632}';  // 
     const ESLINT: char          = '\u{e655}';  // 
     const FILE: char            = '\u{f15b}';  // 
+    const FILE_3D: char         = '\u{f01a7}'; // 󰆧
     const FILE_OUTLINE: char    = '\u{f016}';  // 
     const FOLDER: char          = '\u{e5ff}';  // 
     const FOLDER_CONFIG: char   = '\u{e5fc}';  // 
@@ -37,7 +38,9 @@ impl Icons {
     const FONT: char            = '\u{f031}';  // 
     const GIST_SECRET: char     = '\u{eafa}';  // 
     const GIT: char             = '\u{f1d3}';  // 
+    const GODOT: char           = '\u{e65f}';  // 
     const GRADLE: char          = '\u{e660}';  // 
+    const GRAPHQL: char         = '\u{e662}';  // 
     const GRUNT: char           = '\u{e611}';  // 
     const GULP: char            = '\u{e610}';  // 
     const HTML5: char           = '\u{f13b}';  // 
@@ -52,6 +55,7 @@ impl Icons {
     const LANG_CSHARP: char     = '\u{f031b}'; // 󰌛
     const LANG_D: char          = '\u{e7af}';  // 
     const LANG_ELIXIR: char     = '\u{e62d}';  // 
+    const LANG_FORTRAN: char    = '\u{f121a}'; // 󱈚
     const LANG_FSHARP: char     = '\u{e7a7}';  // 
     const LANG_GO: char         = '\u{e65e}';  // 
     const LANG_GROOVY: char     = '\u{e775}';  // 
@@ -59,6 +63,7 @@ impl Icons {
     const LANG_JAVA: char       = '\u{e256}';  // 
     const LANG_JAVASCRIPT: char = '\u{e74e}';  // 
     const LANG_KOTLIN: char     = '\u{e634}';  // 
+    const LANG_NIM: char        = '\u{e677}';  // 
     const LANG_OCAML: char      = '\u{e67a}';  // 
     const LANG_PERL: char       = '\u{e67e}';  // 
     const LANG_PHP: char        = '\u{e73d}';  // 
@@ -150,6 +155,8 @@ const DIRECTORY_ICONS: Map<&'static str, char> = phf_map! {
     "Videos"              => '\u{f03d}',            // 
     "xbps.d"              => Icons::FOLDER_CONFIG,  // 
     "xorg.conf.d"         => Icons::FOLDER_CONFIG,  // 
+    "hi"                  => Icons::BINARY,         // 
+    "cabal"               => Icons::LANG_HASKELL,   // 
 };
 
 /// Mapping from full filenames to file icon. This mapping should also contain
@@ -233,6 +240,9 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "csh.logout"          => Icons::SHELL,          // 󱆃
     "docker-compose.yml"  => Icons::DOCKER,         // 
     "Dockerfile"          => Icons::DOCKER,         // 
+    "compose.yaml"        => Icons::DOCKER,         // 
+    "compose.yml"         => Icons::DOCKER,         // 
+    "docker-compose.yaml" => Icons::DOCKER,         // 
     "dune"                => Icons::LANG_OCAML,     // 
     "dune-project"        => Icons::WRENCH,          // 
     "Earthfile"           => '\u{f0ac}',            // 
@@ -290,6 +300,7 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
     "passwd"              => Icons::LOCK,           // 
     "php.ini"             => Icons::LANG_PHP,       // 
     "PKGBUILD"            => '\u{f303}',            // 
+    "platformio.ini"      => '\u{e682}',            // 
     "pom.xml"             => '\u{e674}',            // 
     "Procfile"            => '\u{e77b}',            // 
     "profile"             => Icons::SHELL,          // 󱆃
@@ -320,10 +331,12 @@ const FILENAME_ICONS: Map<&'static str, char> = phf_map! {
 /// Mapping from lowercase file extension to icons.  If an image, video, or audio extension is add
 /// also update the extension filetype map.
 const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
+    "3mf"            => Icons::FILE_3D,          // 󰆧
     "7z"             => Icons::COMPRESSED,       // 
     "a"              => Icons::OS_LINUX,         // 
     "acc"            => Icons::AUDIO,            // 
     "acf"            => '\u{f1b6}',              // 
+    "age"            => Icons::SHIELD_LOCK,      // 󰦝
     "ai"             => '\u{e7b4}',              // 
     "aif"            => Icons::AUDIO,            // 
     "aifc"           => Icons::AUDIO,            // 
@@ -349,6 +362,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "bdf"            => Icons::FONT,             // 
     "bib"            => Icons::LANG_TEX,         // 
     "bin"            => Icons::BINARY,           // 
+    "blend"          => '\u{f00ab}',             // 󰂫
     "bmp"            => Icons::IMAGE,            // 
     "br"             => Icons::COMPRESSED,       // 
     "bst"            => Icons::LANG_TEX,         // 
@@ -408,6 +422,8 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "docx"           => Icons::DOCUMENT,         // 
     "dot"            => '\u{f1049}',             // 󱁉
     "download"       => Icons::DOWNLOAD,         // 󰇚
+    "dockerfile"     => Icons::DOCKER,           // 
+    "dockerignore"   => Icons::DOCKER,           // 
     "drawio"         => '\u{ebba}',              // 
     "dump"           => Icons::DATABASE,         // 
     "dvi"            => Icons::IMAGE,            // 
@@ -418,6 +434,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ejs"            => '\u{e618}',              // 
     "el"             => Icons::EMACS,            // 
     "elc"            => Icons::EMACS,            // 
+    "elf"            => Icons::BINARY,           // 
     "elm"            => '\u{e62c}',              // 
     "eml"            => '\u{f003}',              // 
     "env"            => '\u{f462}',              // 
@@ -429,16 +446,27 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ex"             => Icons::LANG_ELIXIR,      // 
     "exe"            => Icons::OS_WINDOWS_CMD,   // 
     "exs"            => Icons::LANG_ELIXIR,      // 
+    "f"              => Icons::LANG_FORTRAN,     // 󱈚
+    "f90"            => Icons::LANG_FORTRAN,     // 󱈚
+    "fbx"            => Icons::FILE_3D,          // 󰆧
     "fdmdownload"    => Icons::DOWNLOAD,         // 󰇚
     "fish"           => Icons::SHELL_CMD,        // 
     "flac"           => Icons::AUDIO,            // 
     "flv"            => Icons::VIDEO,            // 
     "fnt"            => Icons::FONT,             // 
+    "fodg"           => Icons::VECTOR,           // 󰕙
+    "fodp"           => Icons::SLIDE,            // 
+    "fods"           => Icons::SHEET,            // 
+    "fodt"           => Icons::DOCUMENT,         // 
     "fon"            => Icons::FONT,             // 
     "font"           => Icons::FONT,             // 
+    "for"            => Icons::LANG_FORTRAN,     // 󱈚
     "fs"             => Icons::LANG_FSHARP,      // 
     "fsi"            => Icons::LANG_FSHARP,      // 
+    "fsproj"         => Icons::LANG_FSHARP,      // 
     "fsx"            => Icons::LANG_FSHARP,      // 
+    "gcode"          => '\u{f0af4}',             // 󰫴
+    "gd"             => Icons::GODOT,            // 
     "gdoc"           => Icons::DOCUMENT,         // 
     "gem"            => Icons::LANG_RUBY,        // 
     "gemfile"        => Icons::LANG_RUBY,        // 
@@ -447,8 +475,11 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "gif"            => Icons::IMAGE,            // 
     "git"            => Icons::GIT,              // 
     "go"             => Icons::LANG_GO,          // 
+    "godot"          => Icons::GODOT,            // 
     "gpg"            => Icons::SHIELD_LOCK,      // 󰦝
+    "gql"            => Icons::GRAPHQL,          // 
     "gradle"         => Icons::GRADLE,           // 
+    "graphql"        => Icons::GRAPHQL,          // 
     "groovy"         => Icons::LANG_GROOVY,      // 
     "gsheet"         => Icons::SHEET,            // 
     "gslides"        => Icons::SLIDE,            // 
@@ -464,6 +495,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "heic"           => Icons::IMAGE,            // 
     "heics"          => Icons::VIDEO,            // 
     "heif"           => Icons::IMAGE,            // 
+    "hex"            => '\u{f12a7}',             // 󱊧
     "hpp"            => Icons::LANG_CPP,         // 
     "hs"             => Icons::LANG_HASKELL,     // 
     "htm"            => Icons::HTML5,            // 
@@ -477,8 +509,8 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "image"          => Icons::DISK_IMAGE,       // 
     "img"            => Icons::DISK_IMAGE,       // 
     "iml"            => Icons::INTELLIJ,         // 
-    "inl"            => Icons::LANG_C,           // 
     "ini"            => Icons::CONFIG,           // 
+    "inl"            => Icons::LANG_C,           // 
     "ipynb"          => '\u{e678}',              // 
     "iso"            => Icons::DISK_IMAGE,       // 
     "j2c"            => Icons::IMAGE,            // 
@@ -560,10 +592,16 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "mts"            => Icons::LANG_TYPESCRIPT,  // 
     "mustache"       => Icons::MUSTACHE,         // 
     "nef"            => Icons::IMAGE,            // 
+    "nim"            => Icons::LANG_NIM,         // 
+    "nimble"         => Icons::LANG_NIM,         // 
+    "nims"           => Icons::LANG_NIM,         // 
     "ninja"          => '\u{f0774}',             // 󰝴
     "nix"            => '\u{f313}',              // 
     "node"           => Icons::NODEJS,           // 
     "o"              => Icons::BINARY,           // 
+    "obj"            => Icons::FILE_3D,          // 󰆧
+    "odf"            => '\u{f0784}',             // 󰞄
+    "odg"            => Icons::VECTOR,           // 󰕙
     "odp"            => Icons::SLIDE,            // 
     "ods"            => Icons::SHEET,            // 
     "odt"            => Icons::DOCUMENT,         // 
@@ -591,6 +629,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "pl"             => Icons::LANG_PERL,        // 
     "plist"          => Icons::OS_APPLE,         // 
     "plx"            => Icons::LANG_PERL,        // 
+    "ply"            => Icons::FILE_3D,          // 󰆧
     "pm"             => Icons::LANG_PERL,        // 
     "png"            => Icons::IMAGE,            // 
     "pnm"            => Icons::IMAGE,            // 
@@ -643,6 +682,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ru"             => Icons::LANG_RUBY,        // 
     "rubydoc"        => Icons::LANG_RUBYRAILS,   // 
     "s"              => Icons::LANG_ASSEMBLY,    // 
+    "sal"            => '\u{f147b}',             // 󱑻
     "sass"           => Icons::LANG_SASS,        // 
     "sbt"            => Icons::SUBTITLE,         // 󰨖
     "scala"          => '\u{e737}',              // 
@@ -663,9 +703,10 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "so"             => Icons::OS_LINUX,         // 
     "sql"            => Icons::DATABASE,         // 
     "sqlite3"        => '\u{e7c4}',              // 
+    "sr"             => '\u{f147b}',             // 󱑻
     "srt"            => Icons::SUBTITLE,         // 󰨖
     "ssa"            => Icons::SUBTITLE,         // 󰨖
-    "stl"            => Icons::IMAGE,            // 
+    "stl"            => Icons::FILE_3D,          // 󰆧
     "sty"            => Icons::LANG_TEX,         // 
     "styl"           => Icons::LANG_STYLUS,      // 
     "stylus"         => Icons::LANG_STYLUS,      // 
@@ -700,7 +741,9 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "tml"            => Icons::CONFIG,           // 
     "toml"           => Icons::CONFIG,           // 
     "torrent"        => '\u{e275}',              // 
+    "tres"           => Icons::GODOT,            // 
     "ts"             => Icons::LANG_TYPESCRIPT,  // 
+    "tscn"           => Icons::GODOT,            // 
     "tsv"            => Icons::SHEET,            // 
     "tsx"            => Icons::REACT,            // 
     "ttc"            => Icons::FONT,             // 
